.. currentmodule:: xrtpy

.. _feedback_communication:

********************
Communication Routes
********************

XRTpy has several methods of contact to get direct intel of XRTpy's current
works, reporting bugs, giving feedback, and asking questions. Please direct any comments, questions, or suggestions to `xrtpy@cfa.harvard.edu`_.

Feedback
========
We appreciate any feedback describing your experience using XRTpy. We welcome other methods and ideas towards the development of XRTpy. You may contact us via `email`_ or through `GitHub Hinode XRT`_.

Bug Encounters
==============
In the event that you come across a direct XRTpy error, flaw, or unexpected operation, please report it to us directly via `email`_ or by creating a `GitHub-issue`_.


.. _xrtpy@cfa.harvard.edu: xrtpy@cfa.harvard.edu
.. _email: xrtpy@cfa.harvard.edu
.. _GitHub-issue: https://github.com/HinodeXRT/xrtpy/issues
.. _GitHub Hinode XRT : https://github.com/HinodeXRT/xrtpy
